import click
import utils
import os


@click.group('Local')
def local():
    pass


@local.command('local', help='Generate Local Template')
@click.option('-a', '--arch', 'ARCH', default='x86_64', help='Architecture of Executable File', show_default=True)
@click.option('--os', 'OS', default='linux', help='OS of Executable File', show_default=True)
@click.option('-e', '--endian', 'ENDIAN', default='little', help='OS of Executable File', show_default=True)
@click.option('-l', '--loglevel', 'LOG_LEVEL', default='info', help='Log Level of pwntools', show_default=True)
@click.option('-r', '--realpath', 'REALPATH', default=False, help='using realpath for Executable File', show_default=True)
@click.option('--libc', 'LIBC', help='Address of LIBC')
@click.option('-o', '--output', 'OUTPUT', help='write to output')
@click.argument('file')
def command(
        file,
        ARCH,
        OS,
        ENDIAN,
        LOG_LEVEL,
        LIBC,
        OUTPUT,
        REALPATH
):
    args = dict(
        ARCH=ARCH,
        OS=OS,
        ENDIAN=ENDIAN,
        LOG_LEVEL=LOG_LEVEL,
        EXEC_FILE=file if not REALPATH else os.path.abspath(file),
        LOCAL=True,
    )

    if LIBC:
        args.update(LIBC=LIBC)

    data = utils.render(utils.TEMPLATES.MAIN, **args)
    if OUTPUT:
        open(OUTPUT, 'w').write(data)
        click.echo("[*] Stored in file '{}'".format(OUTPUT))
    else:
        click.echo(data)



from setuptools import setup, find_packages
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md')) as f:
    long_description = f.read()

setup(
    name='expl',
    version='1.0.1',
    packages=find_packages(exclude=['.venv', '.idea', 'build', 'dist', 'expl.egg-info']),
    url='https://github.com/AlirezaKm/expl',
    license='GPLv3',
    author='Alireza Km',
    author_email='alitm28@gmail.com',
    description='Generate exploit template',
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords=['exploit', 'template', 'generator'],
    include_package_data=True,
    entry_points={
        'console_scripts': [
            'expl=run:app'
        ]
    },
    install_requires=[
        'click',
        'Jinja2',
        'MarkupSafe'
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3',
    ],
)



import click
import utils


@click.group('Remote')
def remote():
    pass


@remote.command('remote', help='Generate Remote Template')
@click.option('-a', '--arch', 'ARCH', default='x86_64', help='Architecture of Executable File', show_default=True)
@click.option('--os', 'OS', default='linux', help='OS of Executable File', show_default=True)
@click.option('-e', '--endian', 'ENDIAN', default='little', help='OS of Executable File', show_default=True)
@click.option('-l', '--loglevel', 'LOG_LEVEL', default='info', help='Log Level of pwntools', show_default=True)
@click.option('--libc', 'LIBC', help='Address of LIBC')
@click.option('-o', '--output', 'OUTPUT', help='write to output')
@click.argument('host')
@click.argument('port')
def command(
        host,
        port,
        ARCH,
        OS,
        ENDIAN,
        LOG_LEVEL,
        LIBC,
        OUTPUT
):
    args = dict(
        ARCH=ARCH,
        OS=OS,
        ENDIAN=ENDIAN,
        LOG_LEVEL=LOG_LEVEL,
        HOST=host,
        PORT=port,
        REMOTE=True,
    )

    if LIBC:
        args.update(LIBC=LIBC)

    data = utils.render(utils.TEMPLATES.MAIN, **args)
    if OUTPUT:
        open(OUTPUT, 'w').write(data)
        click.echo("[*] Stored in file '{}'".format(OUTPUT))
    else:
        click.echo(data)
